import time
from recup import recupfunc

class Valeur(object):	
	def __init__(self,nom,url):
		self.nom=nom
		self.url=url
		self.taux=recupfunc(self.url)
		self.mise=0.0
		self.date=time.time()
		self.validation=0
		self.anulation=0
		self.AVendre = 0
		self.AAnule = 0
	
	"""achat d'une actiont"""
	def Achat(self,mise):
		self.variationAchat=recupfunc(self.url)
		self.date=time.time()
		self.mise=mise
		print ("achat de " + str(mise) + " de " + str(self.nom))
	
	"""vent une transaction si le taux est interesant sinon annulle"""
	def Vente(self):
		self.AVendre=0
		tmp = recupfunc(self.url)[2]
		taux=(tmp-self.taux[2])/100
		if taux < 0:
			Anulation()
		else:
			self.validation = self.validation + 1
			tmpMise=self.mise
			self.mise=0.0
			gainpro = tmpMise*taux
			print ("vente de " + str(tmpMise) + " de " + str(self.nom) + " pour un taux de " + str(taux) + ". Gain " + str(gainpro))
			return gainpro
		
	""" anule une transaction """
	def Anulation(self): # a voir si on regarde pas si on mettrais pas en vente 
		self.AAnule = 0
		self.anulation = self.annulation +1
		print ("annulation de " + str(mise) + " de " + str(self.nom))
		self.mise = 0.0
		
	"""retourne le temps restant en sec avant l'expiration du choix de l'option
	"""
	def tempsRestant(self):
		return 600-(time.time()-self.date)
	
	def getNewTaux(self):
		return recupfunc(self.url)[2]
		
	def MiseEnVente(self):
		self.AVendre=1
	
	def MiseEnAnnulation(self):
		self.AAnule=1
		
	def getAVendre(self):
		return self.AVendre
		
	def getAAnule(self):
		return self.AAnule
	
	def getTaux(self):
		return self.taux[2]
		
	def getMise(self):
		return self.mise
		
	def getNom(self):
		return self.nom
	
